@@ -19,7 +19,7 @@ use aliased 'Devel::Declare::Context::Simple', 'ContextSimple';
 
 use namespace::autoclean;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 has package => (
     is            => 'ro',
@@ -109,7 +109,8 @@ sub strip_name {
     my $line = $ctx->get_linestr;
     my $offset = $ctx->offset;
     local $@;
-    my ($str) = extract_quotelike(substr($line, $offset));
+    my $copy = substr($line, $offset);
+    my ($str) = extract_quotelike($copy);
     return unless defined $str;
 
     return if ($@ && $@ =~ /^No quotelike operator found/);
